#!/bin/sh
#
# Copyright 2009-2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

if [ -n "$1" ]; then
    USER=$1
    echo "Creating Launchpad database for $USER"
else
    echo "usage: launchpad-database-setup DEVELOPER_USER"
    echo "THIS SCRIPT WILL DESTROY ALL POSTGRESQL DATA for the given user"
    echo "If you really want that, run it with the username of your "
    echo "local developer account."
    exit 1
fi

# This attempts to automate instructions provided on
# https://dev.launchpad.net/DatabaseSetup which are intended for
# initial Launchpad setup on an otherwise unconfigured postgresql instance

for pgversion in 9.1
do
  sudo grep -q "^auto" /etc/postgresql/$pgversion/main/start.conf
  if [ $? -eq 0 ]; then
    break
  fi
done

if [ -z "$pgversion" ]
then
  echo "Unable to determine your postgres version."
  exit 1
fi

echo "Using postgres $pgversion"

# Make sure that we have the correct version running on port 5432
sudo grep -q "port.*5432" /etc/postgresql/$pgversion/main/postgresql.conf
if [ $? -ne 0 ]; then
  echo "Please check /etc/postgresql/$pgversion/main/postgresql.conf and"
  echo "ensure postgres is running on port 5432."
fi;

if [ -e /etc/init.d/postgresql-$pgversion ]; then
    sudo /etc/init.d/postgresql-$pgversion stop
else
    # This is Maverick.
    sudo /etc/init.d/postgresql stop $pgversion
fi

echo Purging postgresql data...
sudo pg_dropcluster $pgversion main --stop-server
echo Re-creating postgresql database...
# Setting locale to C to make the server run in that locale.
LC_ALL=C sudo pg_createcluster $pgversion main --encoding UNICODE

echo Applying postgresql configuration changes...

sudo cp -a /etc/postgresql/$pgversion/main/pg_hba.conf \
    /etc/postgresql/$pgversion/main/pg_hba.conf.old
sudo dd of=/etc/postgresql/$pgversion/main/pg_hba.conf <<'EOF'
# Launchpad users
# This section added automatically by launchpad-database-setup
local   all         all                           trust
host    all         all         127.0.0.1/32      trust
host    all         all         ::1/128           trust
# END Launchpad users

EOF
sudo dd oflag=append conv=notrunc \
    if=/etc/postgresql/$pgversion/main/pg_hba.conf.old \
    of=/etc/postgresql/$pgversion/main/pg_hba.conf
sudo chown --reference=/etc/postgresql/$pgversion/main/pg_hba.conf.old \
    /etc/postgresql/$pgversion/main/pg_hba.conf
sudo chmod --reference=/etc/postgresql/$pgversion/main/pg_hba.conf.old \
    /etc/postgresql/$pgversion/main/pg_hba.conf

sudo grep -q Launchpad /etc/postgresql/$pgversion/main/postgresql.conf || \
sudo tee -a /etc/postgresql/$pgversion/main/postgresql.conf <<'EOF'

##
## Launchpad configuration
##
# Enable launchpad full text searching in database
search_path='$user,public,ts2'
# Per Bug #90809, standard_conforming_strings should be 'on'
standard_conforming_strings=off
escape_string_warning=off

#enable_seqscan=false
log_statement='none'
log_line_prefix='[%t] %q%u@%d '
fsync = off

EOF

if [ -e /etc/init.d/postgresql-$pgversion ]; then
    sudo /etc/init.d/postgresql-$pgversion start
else
    # This is Maverick.
    sudo /etc/init.d/postgresql start $pgversion
fi

echo Waiting 10 seconds for postgresql to come up...
sleep 10

echo Creating postgresql user $USER
sudo -u postgres /usr/lib/postgresql/$pgversion/bin/createuser -a -d $USER

echo
echo Looks like everything went ok.
echo Now run '"make schema"' at the top level of the launchpad tree.

exit 0
